@@ -16,13 +16,19 @@ erect2qtvr
 jpeg2qtvr
 match-n-shift
 nona-mask
+pafextract
+panostart
 process-masks
 pto2fulla
 pto2tiff
-ptomerge
+ptocentre
+ptoclean
+ptoget
 ptograph
 ptoinfo
+ptomerge
 ptopath
+ptoset
 ptosort
 ptosplit
 qtvr2erect
